@@ -8,20 +8,16 @@
 #ifndef INCLUDED_IXION_CELL_QUEUE_MANAGER_HPP
 #define INCLUDED_IXION_CELL_QUEUE_MANAGER_HPP
 
-#include "ixion/global.hpp"
+#include <ixion/global.hpp>
 
 #include <memory>
 #include <vector>
 
 namespace ixion {
 
-struct abs_address_t;
-
-namespace iface {
-
-class formula_model_access;
-
-}
+class formula_cell;
+class model_context;
+struct queue_entry;
 
 /**
  * Class that manages multi-threaded calculation of formula cells.
@@ -35,8 +31,8 @@ public:
     formula_cell_queue() = delete;
 
     formula_cell_queue(
-        iface::formula_model_access& cxt,
-        std::vector<abs_address_t>&& cells,
+        model_context& cxt,
+        std::vector<queue_entry>&& cells,
         size_t thread_count);
 
     ~formula_cell_queue();
