@@ -13,7 +13,8 @@ config::config() :
     sep_function_arg(','),
     sep_matrix_column(','),
     sep_matrix_row(';'),
-    output_precision(-1) {}
+    output_precision(-1)
+{}
 
 config::config(const config& r) :
     sep_function_arg(r.sep_function_arg),
